@@ -111,7 +111,7 @@ void LOW_helper_msglog::printPerror( const int inErrno, const char *inFormat, ..
   va_start( inParamList, inFormat);
   length += vsnprintf( &dummy, 0, inFormat, inParamList);
   va_end( inParamList);
-  if ( inErrno < sys_nerr-1 ) {
+  if ( inErrno > 0 && inErrno < sys_nerr-1 ) {
     length += strlen( ": ");
     length += strlen( sys_errlist[inErrno]);
   }
@@ -122,7 +122,7 @@ void LOW_helper_msglog::printPerror( const int inErrno, const char *inFormat, ..
   va_start( inParamList, inFormat);
   vsprintf( buffer, inFormat, inParamList);
   va_end( inParamList);
-  if ( inErrno < sys_nerr-1 ) {
+  if ( inErrno > 0 && inErrno < sys_nerr-1 ) {
     strcat( buffer, ": ");
     strcat( buffer, sys_errlist[inErrno]);
   }
