@@ -128,12 +128,19 @@ public:
   // methods
   //
 
-  /** Get the device's family name.
+  /** Get the device's family code.
+      <B>Note:</B> Subclasses must implement this method to return their specific family code.
       @return Family name of the device.
    */
-  virtual std::string getFamilyName() const { return familyName; };
+  virtual const LOW_deviceIDRaw::devFamCode_t getFamilyCode() const { return familyCode; };
+
+  /** Get the device's family name.
+      <B>Note:</B> Subclasses must implement this method to return a clear text
+                   name of their family.
+      @return Family name of the device.
+   */
+  virtual const std::string getFamilyName() const { return familyName; };
 
-  
   /** Get whether the device is externally powered.
       No real activity on the 1-Wire bus occures.
       @return Boolean value indicating status of external power.
