@@ -45,9 +45,12 @@ LOW_device* LOW_deviceFactory::new_SpecificDevice( LOW_netSegment &inSegment, co
   ctorFktMap_t::iterator foundCnstr = deviceCtorsSingleton->find( inDevID.getFamilyCode());
   
   if ( foundCnstr == deviceCtorsSingleton->end() )
-    throw deviceFactory_error( "Family type unknown. Family code: "+inDevID.getFamilyCode(), __FILE__, __LINE__);
-  
-  return foundCnstr->second( inSegment, inDevID);
+    if ( unknownDevCtor == 0 )
+      throw deviceFactory_error( "Family code unknown and no constructor for unknown devices registered.", __FILE__, __LINE__);
+    else
+      return unknownDevCtor( inSegment, inDevID);
+  else
+    return foundCnstr->second( inSegment, inDevID);
 }
 
 
@@ -58,13 +61,19 @@ void LOW_deviceFactory::registerSpecificCtor( LOW_deviceIDRaw::devFamCode_t inFa
     deviceCtorsSingleton = new ctorFktMap_t();
 
   if ( inFamCode == LOW_device::anyDev_famCode )
-    throw deviceFactory_error( "Cannot register for anyDev_famCode.", __FILE__, __LINE__);  
+    throw deviceFactory_error( "Cannot register for anyDev_famCode.", __FILE__, __LINE__);
 
-  if ( (*deviceCtorsSingleton)[inFamCode] != 0 )
-    throw deviceFactory_error( "Familiy type already registered. Family code: "+
-                               inFamCode, __FILE__, __LINE__);
-                    
-  (*deviceCtorsSingleton)[inFamCode] = inPseudoCnstr;
+  if ( inFamCode == LOW_device::unknownDev_famCode ) {
+    if ( unknownDevCtor != 0 )
+      throw deviceFactory_error( "Constructor for unknown devices already registered.", __FILE__, __LINE__);
+    unknownDevCtor = inPseudoCnstr;
+  }
+  else {
+    if ( (*deviceCtorsSingleton)[inFamCode] != 0 )
+      throw deviceFactory_error( "Familiy type already registered. Family code: "+
+                                 inFamCode, __FILE__, __LINE__);
+    (*deviceCtorsSingleton)[inFamCode] = inPseudoCnstr;
+  }
 }
 
 
@@ -77,3 +86,5 @@ void LOW_deviceFactory::registerSpecificCtor( LOW_deviceIDRaw::devFamCode_t inFa
 // Do not really initialize here! Must use singleton pattern!
 LOW_deviceFactory::ctorFktMap_t*  LOW_deviceFactory::deviceCtorsSingleton = 0;
 
+LOW_deviceFactory::newInstanceFkt_t LOW_deviceFactory::unknownDevCtor = 0;
+
