@@ -107,6 +107,11 @@ private:
    */
   static ctorFktMap_t  *deviceCtorsSingleton;
 
+  /** Pseudo constructor for unknown device types.
+      This constructor is used when no specific constructor is found.
+   */
+  static newInstanceFkt_t unknownDevCtor;
+
 
   //=====================================================================================
   //
