@@ -59,6 +59,15 @@ class LOW_linkDS2490 : public LOW_link, public LOW_linkFlexibleSpeed {
 //=======================================================================================
 public:
 
+  //=====================================================================================
+  //
+  // constants
+  //
+
+  static const LOW_portUsbDevice::usbVendorID_t   usbVendorID  = 0x04fa;        /**< Dallas/Maxim USB vendor ID. */
+  static const LOW_portUsbDevice::usbProductID_t  usbProductID = 0x2490;        /**< Dallas/Maxim USB DS2490 product ID. */
+
+
   //=====================================================================================
   //
   // constructors
@@ -77,18 +86,6 @@ public:
                   const bool inHasExternalPower, const bool inAllowProgPulse = false);
 
                   
-  /** Constructor.
-      Automatically finds the first DS2490 on USB bus(es) and uses it.
-
-      Timings for flexible speed is configured to the recommeded optimal parameters
-      as of app note #148.
-
-      @param  inHasExternalPower  Whether the attached bus supplies external power.
-      @param  inAllowProgPulse    Whether the program pulse should be allowed.
-   */
-  LOW_linkDS2490( const bool inHasExternalPower, const bool inAllowProgPulse = false);
-
-  
   /** Destructor.
    */
   virtual ~LOW_linkDS2490();
@@ -168,8 +165,6 @@ private:
 
   //! @name USB related constants.
   //!@{
-  static const LOW_portUsbDevice::usbVendorID_t   usbVendorID  = 0x04fa;        /**< Dallas/Maxim USB vendor ID. */
-  static const LOW_portUsbDevice::usbProductID_t  usbProductID = 0x2490;        /**< Dallas/Maxim USB DS2490 product ID. */
   static const LOW_portUsbDevice::usbInterface_t  usbDefaultInterface = 0;      /**< Default and only USB interface of DS2490. */
   static const LOW_portUsbDevice::bmRequestType_t vendorCmd_requestType = 0x40; /**< Request type of DS2490 vendor specific commands. */
   //!@}
