@@ -110,6 +110,8 @@ template<class devType> std::vector<devType*> hlp_selectDevices( std::vector<dev
       if ( index( acceptChars, key) != 0 ) {
         break;
       }
+      if ( key == 27 ) // ESC
+        throw hlp_userAbort( "Selection aborted by user.", __FILE__, __LINE__);
     }
 
     if      ( key==' ' ) {
@@ -169,6 +171,8 @@ template<class devType> devType* hlp_selectSingleDevice( std::vector<devType*> &
     if ( index( acceptChars, key) != 0 ) {
       break;
     }
+    if ( key == 27 ) // ESC
+      throw hlp_userAbort( "Selection aborted by user.", __FILE__, __LINE__);
   }
 
   printf( "%c\n", key);
@@ -236,6 +240,8 @@ template<class linkType_t> linkType_t* hlp_selectSingleLink( LOW_link::linkPtrVe
     if ( index( acceptChars, key) != 0 ) {
       break;
     }
+    if ( key == 27 ) // ESC
+      throw hlp_userAbort( "Selection aborted by user.", __FILE__, __LINE__);
   }
 
   printf( "%c\n", key);
